# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/litecms/restaurant/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {

        "psr-4": {
            ... ,
            "Litecms\\Restaurant\\": "packages/litecms/restaurant/src",
            "Litecms\\Restaurant\\Seeders\\": "packages/litecms/restaurant/database/seeders"
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Litecms\Restaurant\Providers\RestaurantServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Restaurant'  => Litecms\Restaurant\Facades\Restaurant::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Litecms\\Restaurant\\Seeders\\RestaurantTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Litecms\Restaurant\Providers\RestaurantServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Litecms\Restaurant\Providers\RestaurantServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Litecms\Restaurant\Providers\RestaurantServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/restaurant/{modulename}

**User**

    http://path-to-route-folder/user/restaurant/{modulename}

**Public**

    http://path-to-route-folder/restaurants


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/restaurant/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/restaurant/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/restaurant/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/restaurant/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/restaurant/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/restaurant/{modulename}/{slug}
    METHOD: GET