<?php

namespace Litecms\Restaurant\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Litecms\Restaurant\Models\Restaurant;

class RestaurantPolicy
{

    /**
     * Determine if the given user can view the restaurant.
     *
     * @param UserPolicyInterface $authUser
     * @param Restaurant $restaurant
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Restaurant $restaurant)
    {
        if ($authUser->canDo('restaurant.restaurant.view') && $authUser->isAdmin()) {
            return true;
        }

        return $restaurant->user_id == user_id() && $restaurant->user_type == user_type();
    }

    /**
     * Determine if the given user can create a restaurant.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('restaurant.restaurant.create');
    }

    /**
     * Determine if the given user can update the given restaurant.
     *
     * @param UserPolicyInterface $authUser
     * @param Restaurant $restaurant
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Restaurant $restaurant)
    {
        if ($authUser->canDo('restaurant.restaurant.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $restaurant->user_id == user_id() && $restaurant->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given restaurant.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Restaurant $restaurant)
    {
        return $restaurant->user_id == user_id() && $restaurant->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given restaurant.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Restaurant $restaurant)
    {
        if ($authUser->canDo('restaurant.restaurant.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given restaurant.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Restaurant $restaurant)
    {
        if ($authUser->canDo('restaurant.restaurant.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
